@@ -1,5 +1,7 @@
+#' @importFrom R6 R6Class
+
 .onLoad = function(libname, pkgname) {
-  options(set6.unicode = TRUE)
+  options(set6.unicode = l10n_info()$`UTF-8`)
 }
 
 .onUnload = function(libname, pkgname) {
