@@ -12,28 +12,7 @@ test_that("construction",{
   expect_silent(Set$new(Set$new(2), Interval$new(1,5)))
   expect_error(Set$new(1,2,universe = c(1,2,3)))
   expect_silent(Set$new(1,2,universe = Set$new(1,2,3)))
-})
-
-test_that("inherited_methods",{
   expect_equal(Set$new(1,2)$type,"{}")
-  # expect_equal(Set$new(1,2)$max,2)
-  # expect_equal(Set$new(1,2)$min,1)
-  # expect_equal(Set$new(1,2)$upper,2)
-  # expect_equal(Set$new(1,2)$lower,1)
-  # expect_equal(Set$new()$upper,NA)
-  # expect_equal(Set$new()$lower,NA)
-  # expect_equal(Set$new()$max,NaN)
-  # expect_equal(Set$new()$min,NaN)
-  # expect_equal(Set$new("a",2)$max, NaN)
-  # expect_equal(Set$new("a",2)$min, NaN)
-  # expect_equal(Set$new("a",2)$upper, 2)
-  # expect_equal(Set$new("a",2)$lower, "a")
-  # expect_equal(Set$new(1,2)$class, "numeric")
-  # expect_equal(Set$new(Set$new(1),Set$new())$class, "Set")
-  # expect_equal(Set$new(1, "a")$class, "multiple")
-  # expect_equal(Set$new(1,2,3)$range,2)
-  # expect_equal(Set$new(1,"a")$range, numeric(0))
-  expect_equal(setcomplement(Set$new(1,2,universe = Set$new(1,2,3))),Set$new(3))
 })
 
 test_that("elements",{
@@ -46,6 +25,14 @@ test_that("elements",{
   expect_equal(Set$new(Set$new(2), Interval$new(1,5))$elements, c(Set$new(2),Interval$new(1,5)))
 })
 
+test_that("numerics",{
+  expect_equal(Set$new(1)$lower, 1)
+  expect_equal(Set$new(1)$min, NaN)
+  expect_equal(Set$new(1)$upper, 1)
+  expect_equal(Set$new(1)$max, NaN)
+  expect_equal(Set$new(1)$range, NaN)
+})
+
 test_that("length",{
   expect_equal(Set$new(1,2,3)$length, 3)
   expect_equal(Set$new(1,2,3,2,1)$length, 3)
@@ -136,7 +123,39 @@ test_that("as.double",{
 })
 
 test_that("typed set",{
-  expect_equal(Set$new(1.5, class = "integer")$elements, 1L)
+  expect_equal(Set$new(1.5, class = "integer")$elements, list(1L))
   expect_equal(Set$new(1.5, class = "integer")$class, "integer")
+  expect_equal(Set$new(1:5, class = "numeric")$lower, 1)
+  expect_equal(Set$new(1:5, class = "numeric")$min, 1)
+  expect_equal(Set$new(1:5, class = "numeric")$upper, 5)
+  expect_equal(Set$new(1:5, class = "numeric")$max, 5)
+  expect_equal(Set$new(1:2, class = "complex")$upper, 2+0i)
+  expect_equal(Set$new(1:2, class = "complex")$lower, 1+0i)
 })
 
+test_that("add",{
+  expect_equal(Set$new()$add(1), Set$new(1))
+  expect_equal(Set$new(1,2,3)$add(4), Set$new(1,2,3,4))
+  expect_equal(Set$new(1,2,3)$add(4,5), Set$new(1,2,3,4,5))
+  expect_equal(Set$new(1,2, class = "complex")$add(3), Set$new(1:3, class = "complex"))
+  expect_equal(Set$new(1,2,3)$add(Interval$new(5,10)), Set$new(1,2,3,Interval$new(5,10)))
+  expect_silent(Set$new(1,2,3,universe = Interval$new(1,4))$add(4))
+  expect_error(Set$new(1,2,3,universe = Interval$new(1,4))$add(5),"some added")
+  expect_equal(Set$new(1,2)$add(3)$elements, list(1,2,3))
+  expect_equal(Set$new(2, class = "numeric")$add(1)$lower, 1)
+  expect_equal(Set$new(2, class = "numeric")$add(3)$upper, 3)
+  expect_equal(Set$new(2)$add(1)$properties$cardinality, 2)
+  expect_equal(Interval$new(1,2,type = "()")$add(2)$type, "(]")
+})
+
+test_that("remove",{
+  expect_equal(Set$new(1,2)$remove(2), Set$new(1))
+  expect_equal(Set$new(1,2)$remove(1,2), Set$new())
+  expect_equal(Interval$new(1,5)$remove(5),Interval$new(1,5,type="[)"))
+  expect_equal(Interval$new(1,5)$remove(2), Interval$new(1,2,type="[)") + Interval$new(2,5,type="(]"))
+  expect_equal(Set$new(1,2)$remove(2)$elements, list(1))
+  expect_equal(Set$new(1,2,3, class = "numeric")$remove(1)$lower, 2)
+  expect_equal(Set$new(1,2,3, class = "numeric")$remove(3)$upper, 2)
+  expect_equal(Set$new(1,2)$remove(1)$properties$cardinality, 1)
+  expect_equal(Interval$new(1,2,type = "[]")$remove(2)$type, "[)")
+})
